Documentation
¶
Overview ¶
Package client provides a Stripe client for invoking APIs across all resources
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type API ¶
type API struct {
// Account is the client used to invoke /accounts APIs.
Account *account.Client
// AccountLink is the client used to invoke /account_links APIs.
AccountLinks *accountlink.Client
// ApplePayDomains is the client used to invoke /apple_pay/domains APIs.
ApplePayDomains *applepaydomain.Client
// Balance is the client used to invoke /balance APIs.
Balance *balance.Client
// BalanceTransaction is the client used to invoke /balance_transactions APIs.
BalanceTransaction *balancetransaction.Client
// BankAccounts is the client used to invoke bank account related APIs.
BankAccounts *bankaccount.Client
// BitcoinReceivers is the client used to invoke /bitcoin/receivers APIs.
BitcoinReceivers *bitcoinreceiver.Client
// BitcoinTransactions is the client used to invoke /bitcoin/transactions APIs.
BitcoinTransactions *bitcointransaction.Client
// Capabilities is the client used to invoke capability related APIs.
Capabilities *capability.Client
// Cards is the client used to invoke card related APIs.
Cards *card.Client
// Charges is the client used to invoke /charges APIs.
Charges *charge.Client
// CheckoutSessions is the client used to invoke /checkout_sessions APIs.
CheckoutSessions *checkoutsession.Client
// CountrySpec is the client used to invoke /country_specs APIs.
CountrySpec *countryspec.Client
// Coupons is the client used to invoke /coupons APIs.
Coupons *coupon.Client
// CreditNotes is the client used to invoke /credit_notes APIs.
CreditNotes *creditnote.Client
// Customers is the client used to invoke /customers APIs.
Customers *customer.Client
// CustomerBalanceTransactions is the client used to invoke /customers/balance_transactions APIs.
CustomerBalanceTransactions *customerbalancetransaction.Client
// Discounts is the client used to invoke discount related APIs.
Discounts *discount.Client
// Disputes is the client used to invoke /disputes APIs.
Disputes *dispute.Client
// EphemeralKeys is the client used to invoke /ephemeral_keys APIs.
EphemeralKeys *ephemeralkey.Client
// Events is the client used to invoke /events APIs.
Events *event.Client
// ExchangeRates is the client used to invoke /exchange_rates APIs.
ExchangeRates *exchangerate.Client
// Fees is the client used to invoke /application_fees APIs.
Fees *fee.Client
// FeeRefunds is the client used to invoke /application_fees/refunds APIs.
FeeRefunds *feerefund.Client
// Files is the client used to invoke the /files APIs.
Files *file.Client
// FileLinks is the client used to invoke the /file_links APIs.
FileLinks *filelink.Client
// Invoices is the client used to invoke /invoices APIs.
Invoices *invoice.Client
// InvoiceItems is the client used to invoke /invoiceitems APIs.
InvoiceItems *invoiceitem.Client
// IssuingAuthorizations is the client used to invoke /issuing/authorizations APIs.
IssuingAuthorizations *authorization.Client
// IssuingCardholders is the client used to invoke /issuing/cardholders APIs.
IssuingCardholders *cardholder.Client
// IssuingCards is the client used to invoke /issuing/cards APIs.
IssuingCards *issuingcard.Client
// IssuingDisputes is the client used to invoke /issuing/disputes APIs.
IssuingDisputes *issuingdispute.Client
// IssuingTransactions is the client used to invoke /issuing/transactions APIs.
IssuingTransactions *transaction.Client
// LoginLinks is the client used to invoke login link related APIs.
LoginLinks *loginlink.Client
// Mandates is the client used to invoke mandates related APIs.
Mandates *mandate.Client
// OAuth is the client used to invoke /oauth APIs.
OAuth *oauth.Client
// Orders is the client used to invoke /orders APIs.
Orders *order.Client
// OrderReturns is the client used to invoke /order_returns APIs.
OrderReturns *orderreturn.Client
// PaymentIntents is the client used to invoke /payment_intents APIs.
PaymentIntents *paymentintent.Client
// PaymentMethods is the client used to invoke /payment_methods APIs.
PaymentMethods *paymentmethod.Client
// PaymentSource is used to invoke customer sources related APIs.
PaymentSource *paymentsource.Client
// Payouts is the client used to invoke /payouts APIs.
Payouts *payout.Client
// Persons is the client used to invoke /account/persons APIs.
Persons *person.Client
// Plans is the client used to invoke /plans APIs.
Plans *plan.Client
// Products is the client used to invoke /products APIs.
Products *product.Client
// RadarEarlyFraudWarnings is the client used to invoke /radar/early_fraud_warnings APIs.
RadarEarlyFraudWarnings *earlyfraudwarning.Client
// RadarValueLists is the client used to invoke /radar/value_lists APIs.
RadarValueLists *valuelist.Client
// RadarValueListItems is the client used to invoke /radar/value_list_items APIs.
RadarValueListItems *valuelistitem.Client
// Recipients is the client used to invoke /recipients APIs.
Recipients *recipient.Client
// Refunds is the client used to invoke /refunds APIs.
Refunds *refund.Client
// ReportRuns is the client used to invoke /reporting/report_runs APIs.
ReportRuns *reportrun.Client
// ReportTypes is the client used to invoke /reporting/report_types APIs.
ReportTypes *reporttype.Client
// Reversals is the client used to invoke /transfers/reversals APIs.
Reversals *reversal.Client
// Reviews is the client used to invoke /reviews APIs.
Reviews *review.Client
// SetupIntents is the client used to invoke /setup_intents APIs.
SetupIntents *setupintent.Client
// SigmaScheduledQueryRuns is the client used to invoke /sigma/scheduled_query_runs APIs.
SigmaScheduledQueryRuns *scheduledqueryrun.Client
// Skus is the client used to invoke /skus APIs.
Skus *sku.Client
// Sources is the client used to invoke /sources APIs.
Sources *source.Client
// SourceTransactions is the client used to invoke source transaction related APIs.
SourceTransactions *sourcetransaction.Client
// Subscriptions is the client used to invoke /subscriptions APIs.
Subscriptions *sub.Client
// SubscriptionItems is the client used to invoke subscription's items related APIs.
SubscriptionItems *subitem.Client
// SubscriptionSchedules is the client used to invoke subscription schedules related APIs.
SubscriptionSchedules *subschedule.Client
// TaxIDs is the client used to invoke /tax_ids APIs.
TaxIDs *taxid.Client
// TaxRates is the client used to invoke /tax_rates APIs.
TaxRates *taxrate.Client
// TerminalConnectionTokens is the client used to invoke /terminal/connectiontokens related APIs.
TerminalConnectionTokens *terminalconnectiontoken.Client
// TerminalLocations is the client used to invoke /terminal/locations related APIs.
TerminalLocations *terminallocation.Client
// TerminalReaders is the client used to invoke /terminal/readers related APIs.
TerminalReaders *terminalreader.Client
// ThreeDSecures is the client used to invoke /3d_secure related APIs.
ThreeDSecures *threedsecure.Client
// Tokens is the client used to invoke /tokens APIs.
Tokens *token.Client
// Topups is the client used to invoke /tokens APIs.
Topups *topup.Client
// Transfers is the client used to invoke /transfers APIs.
Transfers *transfer.Client
// UsageRecords is the client used to invoke usage record related APIs.
UsageRecords *usagerecord.Client
// UsageRecordsummaries is the client used to invoke usage record summary related APIs.
UsageRecordSummaries *usagerecordsummary.Client
// WebhookEndpoints is the client used to invoke usage record related APIs.
WebhookEndpoints *webhookendpoint.Client
}
API is the Stripe client. It contains all the different resources available.
Click to show internal directories.
Click to hide internal directories.